Package: ordr
Title: A 'Tidyverse' Extension for Ordinations and Biplots
Version: 0.2.0
Authors@R: c(
  person("Jason Cory", "Brunson", email = "cornelioid@gmail.com",
    role = c("aut", "cre"), comment = c(ORCID = "0000-0003-3126-9494")),
  person("Emily", "Paul", email = "erpb.71@gmail.com",
    role = "ctb"),
  person("John", "Gracey", email = "jbgracey6@gmail.com",
    role = "aut")
  )
Description: Ordination comprises several multivariate exploratory and
    explanatory techniques with theoretical foundations in geometric data
    analysis; see Podani (2000, ISBN:90-5782-067-6) for techniques and
    applications and Le Roux & Rouanet (2005) <doi:10.1007/1-4020-2236-0> for
    foundations.
    Greenacre (2010, ISBN:978-84-923846) shows how the most established of
    these, including principal components analysis, correspondence analysis,
    multidimensional scaling, factor analysis, and discriminant analysis,
    rely on eigen-decompositions or singular value decompositions of
    pre-processed numeric matrix data.
    These decompositions give rise to a set of shared coordinates along which
    the row and column elements can be measured. The overlay of their
    scatterplots on these axes, introduced by Gabriel (1971)
    <doi:10.1093/biomet/58.3.453>, is called a biplot.
    'ordr' provides inspection, extraction, manipulation, and visualization
    tools for several popular ordination classes supported by a set of recovery
    methods. It is inspired by and designed to integrate into 'Tidyverse'
    workflows provided by Wickham et al (2019) <doi:10.21105/joss.01686>.
Depends: R (>= 3.3.0), ggplot2
Imports: rlang, cli, MASS, stringr, tidyselect, scales, generics,
        magrittr, tibble, tidyr, dplyr, purrr, labeling, ggrepel, gggda
Suggests: testthat, sessioninfo, gridExtra, mlpack, ddalpha, knitr,
        rmarkdown
License: GPL-3
Encoding: UTF-8
LazyData: true
URL: https://github.com/corybrunson/ordr,
        https://corybrunson.github.io/ordr/
BugReports: https://github.com/corybrunson/ordr/issues
RoxygenNote: 7.3.2
Collate: 'aaa-.r' 'biplot-key.r' 'biplot.r' 'coord-scaffold.r' 'data.r'
        'dplyr-verbs.r' 'utils.r' 'ord-recoverers.r'
        'ord-augmentation.r' 'ord-conference.r' 'ord-tbl.r' 'fun-lda.r'
        'fun-lra.r' 'fun-wrap.r' 'geom-interpolation.r' 'geom-origin.r'
        'geom-utils.r' 'layer-utils.r' 'methods-base-eigen.r'
        'methods-base-svd.r' 'methods-mass-correspondence.r'
        'methods-mass-lda.r' 'methods-mass-mca.r' 'methods-ordr-lra.r'
        'methods-stats-cancor.r' 'methods-stats-cmds.r'
        'methods-stats-factanal.r' 'methods-stats-kmeans.r'
        'methods-stats-lm.r' 'methods-stats-prcomp.r'
        'methods-stats-princomp.r' 'ord-annotation.r' 'ord-format.r'
        'ord-negation.r' 'ord-plot.r' 'ord-supplementation.r'
        'ord-tidiers.r' 'ordinate.r' 'ordr.r' 'stat-matrix.r'
        'stat-projection.r' 'stat-utils.r' 'theme-scaffold.r'
        'zzz-biplot-geoms.r' 'zzz-biplot-stats.r' 'zzz.r'
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-07-10 18:38:17 UTC; jasoncorybrunson
Author: Jason Cory Brunson [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-3126-9494>),
  Emily Paul [ctb],
  John Gracey [aut]
Maintainer: Jason Cory Brunson <cornelioid@gmail.com>
Repository: CRAN
Date/Publication: 2025-07-10 21:40:07 UTC
Built: R 4.6.0; ; 2026-04-29 23:25:27 UTC; unix
