# Generated by roxygen2: do not edit by hand

S3method(as.matrix,tbl_ord)
S3method(as_tbl_ord,cancor_ord)
S3method(as_tbl_ord,cmds_ord)
S3method(as_tbl_ord,correspondence)
S3method(as_tbl_ord,eigen)
S3method(as_tbl_ord,eigen_ord)
S3method(as_tbl_ord,factanal)
S3method(as_tbl_ord,kmeans)
S3method(as_tbl_ord,lda)
S3method(as_tbl_ord,lda_ord)
S3method(as_tbl_ord,lm)
S3method(as_tbl_ord,lra)
S3method(as_tbl_ord,mca)
S3method(as_tbl_ord,prcomp)
S3method(as_tbl_ord,princomp)
S3method(as_tbl_ord,svd_ord)
S3method(as_tbl_ord,tbl_ord)
S3method(biplot,lra)
S3method(biplot,tbl_ord)
S3method(dim,tbl_ord)
S3method(format,tbl_ord)
S3method(fortify,tbl_ord)
S3method(ggplot_add,LayerRef)
S3method(glance,tbl_ord)
S3method(lda_ord,data.frame)
S3method(lda_ord,default)
S3method(lda_ord,formula)
S3method(lda_ord,matrix)
S3method(model.frame,lda_ord)
S3method(ordinate,array)
S3method(ordinate,data.frame)
S3method(ordinate,default)
S3method(ordinate,dist)
S3method(ordinate,table)
S3method(plot,lra)
S3method(plot,tbl_ord)
S3method(predict,lda_ord)
S3method(print,lra)
S3method(print,tbl_ord)
S3method(recover_aug_cols,cancor_ord)
S3method(recover_aug_cols,cmds_ord)
S3method(recover_aug_cols,correspondence)
S3method(recover_aug_cols,eigen_ord)
S3method(recover_aug_cols,factanal)
S3method(recover_aug_cols,kmeans)
S3method(recover_aug_cols,lda)
S3method(recover_aug_cols,lda_ord)
S3method(recover_aug_cols,lm)
S3method(recover_aug_cols,lra)
S3method(recover_aug_cols,mca)
S3method(recover_aug_cols,mlm)
S3method(recover_aug_cols,prcomp)
S3method(recover_aug_cols,princomp)
S3method(recover_aug_cols,svd_ord)
S3method(recover_aug_coord,cancor_ord)
S3method(recover_aug_coord,cmds_ord)
S3method(recover_aug_coord,correspondence)
S3method(recover_aug_coord,eigen)
S3method(recover_aug_coord,eigen_ord)
S3method(recover_aug_coord,factanal)
S3method(recover_aug_coord,kmeans)
S3method(recover_aug_coord,lda)
S3method(recover_aug_coord,lda_ord)
S3method(recover_aug_coord,lm)
S3method(recover_aug_coord,lra)
S3method(recover_aug_coord,mca)
S3method(recover_aug_coord,mlm)
S3method(recover_aug_coord,prcomp)
S3method(recover_aug_coord,princomp)
S3method(recover_aug_coord,svd_ord)
S3method(recover_aug_rows,cancor_ord)
S3method(recover_aug_rows,cmds_ord)
S3method(recover_aug_rows,correspondence)
S3method(recover_aug_rows,eigen_ord)
S3method(recover_aug_rows,factanal)
S3method(recover_aug_rows,glm)
S3method(recover_aug_rows,kmeans)
S3method(recover_aug_rows,lda)
S3method(recover_aug_rows,lda_ord)
S3method(recover_aug_rows,lm)
S3method(recover_aug_rows,lra)
S3method(recover_aug_rows,mca)
S3method(recover_aug_rows,mlm)
S3method(recover_aug_rows,prcomp)
S3method(recover_aug_rows,princomp)
S3method(recover_aug_rows,svd_ord)
S3method(recover_cols,cancor_ord)
S3method(recover_cols,cmds_ord)
S3method(recover_cols,correspondence)
S3method(recover_cols,data.frame)
S3method(recover_cols,default)
S3method(recover_cols,eigen)
S3method(recover_cols,eigen_ord)
S3method(recover_cols,factanal)
S3method(recover_cols,kmeans)
S3method(recover_cols,lda)
S3method(recover_cols,lda_ord)
S3method(recover_cols,lm)
S3method(recover_cols,lra)
S3method(recover_cols,mca)
S3method(recover_cols,mlm)
S3method(recover_cols,prcomp)
S3method(recover_cols,princomp)
S3method(recover_cols,svd_ord)
S3method(recover_conference,cancor_ord)
S3method(recover_conference,cmds_ord)
S3method(recover_conference,correspondence)
S3method(recover_conference,default)
S3method(recover_conference,eigen)
S3method(recover_conference,eigen_ord)
S3method(recover_conference,factanal)
S3method(recover_conference,lda)
S3method(recover_conference,lda_ord)
S3method(recover_conference,lra)
S3method(recover_conference,mca)
S3method(recover_conference,prcomp)
S3method(recover_conference,princomp)
S3method(recover_conference,svd_ord)
S3method(recover_coord,cancor_ord)
S3method(recover_coord,cmds_ord)
S3method(recover_coord,correspondence)
S3method(recover_coord,data.frame)
S3method(recover_coord,default)
S3method(recover_coord,eigen)
S3method(recover_coord,eigen_ord)
S3method(recover_coord,factanal)
S3method(recover_coord,kmeans)
S3method(recover_coord,lda)
S3method(recover_coord,lda_ord)
S3method(recover_coord,lm)
S3method(recover_coord,lra)
S3method(recover_coord,mca)
S3method(recover_coord,mlm)
S3method(recover_coord,prcomp)
S3method(recover_coord,princomp)
S3method(recover_coord,svd_ord)
S3method(recover_inertia,cancor_ord)
S3method(recover_inertia,cmds_ord)
S3method(recover_inertia,correspondence)
S3method(recover_inertia,default)
S3method(recover_inertia,eigen)
S3method(recover_inertia,eigen_ord)
S3method(recover_inertia,factanal)
S3method(recover_inertia,lda)
S3method(recover_inertia,lda_ord)
S3method(recover_inertia,lra)
S3method(recover_inertia,mca)
S3method(recover_inertia,prcomp)
S3method(recover_inertia,princomp)
S3method(recover_inertia,svd_ord)
S3method(recover_rows,cancor_ord)
S3method(recover_rows,cmds_ord)
S3method(recover_rows,correspondence)
S3method(recover_rows,data.frame)
S3method(recover_rows,default)
S3method(recover_rows,eigen)
S3method(recover_rows,eigen_ord)
S3method(recover_rows,factanal)
S3method(recover_rows,kmeans)
S3method(recover_rows,lda)
S3method(recover_rows,lda_ord)
S3method(recover_rows,lm)
S3method(recover_rows,lra)
S3method(recover_rows,mca)
S3method(recover_rows,mlm)
S3method(recover_rows,prcomp)
S3method(recover_rows,princomp)
S3method(recover_rows,svd_ord)
S3method(recover_supp_cols,cancor_ord)
S3method(recover_supp_cols,default)
S3method(recover_supp_rows,cancor_ord)
S3method(recover_supp_rows,default)
S3method(recover_supp_rows,factanal)
S3method(recover_supp_rows,lda)
S3method(recover_supp_rows,lda_ord)
S3method(recover_supp_rows,mca)
S3method(recover_supp_rows,princomp)
S3method(screeplot,lra)
S3method(screeplot,tbl_ord)
S3method(stats::model.frame,lda_ord)
S3method(tidy,tbl_ord)
export("%>%")
export(CoordScaffold)
export(GeomInterpolation)
export(GeomOrigin)
export(GeomUnitCircle)
export(StatCols)
export(StatColsBagplot)
export(StatColsCenter)
export(StatColsChull)
export(StatColsCone)
export(StatColsDensity2d)
export(StatColsDensity2dFilled)
export(StatColsDepth)
export(StatColsDepthFilled)
export(StatColsEllipse)
export(StatColsPeel)
export(StatColsProjection)
export(StatColsRule)
export(StatColsScale)
export(StatColsSpantree)
export(StatColsStar)
export(StatProjection)
export(StatRows)
export(StatRowsBagplot)
export(StatRowsCenter)
export(StatRowsChull)
export(StatRowsCone)
export(StatRowsDensity2d)
export(StatRowsDensity2dFilled)
export(StatRowsDepth)
export(StatRowsDepthFilled)
export(StatRowsEllipse)
export(StatRowsPeel)
export(StatRowsProjection)
export(StatRowsRule)
export(StatRowsScale)
export(StatRowsSpantree)
export(StatRowsStar)
export(as_tbl_ord)
export(augment_ord)
export(cancor_ord)
export(cbind_cols)
export(cbind_rows)
export(cmdscale_ord)
export(confer_inertia)
export(coord_scaffold)
export(draw_key_crosslines)
export(draw_key_crosspoint)
export(draw_key_line)
export(eigen_ord)
export(geom_axis)
export(geom_bagplot)
export(geom_cols_axis)
export(geom_cols_bagplot)
export(geom_cols_contour)
export(geom_cols_density_2d)
export(geom_cols_density_2d_filled)
export(geom_cols_interpolation)
export(geom_cols_isoline)
export(geom_cols_label)
export(geom_cols_label_repel)
export(geom_cols_lineranges)
export(geom_cols_path)
export(geom_cols_point)
export(geom_cols_pointranges)
export(geom_cols_polygon)
export(geom_cols_rule)
export(geom_cols_text)
export(geom_cols_text_radiate)
export(geom_cols_text_repel)
export(geom_cols_vector)
export(geom_interpolation)
export(geom_isoline)
export(geom_label_repel)
export(geom_lineranges)
export(geom_origin)
export(geom_pointranges)
export(geom_rows_axis)
export(geom_rows_bagplot)
export(geom_rows_contour)
export(geom_rows_density_2d)
export(geom_rows_density_2d_filled)
export(geom_rows_interpolation)
export(geom_rows_isoline)
export(geom_rows_label)
export(geom_rows_label_repel)
export(geom_rows_lineranges)
export(geom_rows_path)
export(geom_rows_point)
export(geom_rows_pointranges)
export(geom_rows_polygon)
export(geom_rows_rule)
export(geom_rows_text)
export(geom_rows_text_radiate)
export(geom_rows_text_repel)
export(geom_rows_vector)
export(geom_rule)
export(geom_text_radiate)
export(geom_text_repel)
export(geom_unit_circle)
export(geom_vector)
export(get_cols)
export(get_conference)
export(get_coord)
export(get_inertia)
export(get_negation)
export(get_rows)
export(ggbiplot)
export(glance)
export(is.sync)
export(is.tbl_ord)
export(is_tbl_ord)
export(lda_ord)
export(left_join_cols)
export(left_join_rows)
export(lra)
export(make_tbl_ord)
export(maxpp)
export(minabspp)
export(minpp)
export(mutate_cols)
export(mutate_rows)
export(negate_ord)
export(negate_to_first_orthant)
export(ord_aes)
export(ordinate)
export(position_nudge_repel)
export(pull_cols)
export(pull_rows)
export(recover_aug_cols)
export(recover_aug_coord)
export(recover_aug_rows)
export(recover_cols)
export(recover_conference)
export(recover_coord)
export(recover_inertia)
export(recover_rows)
export(recover_supp_cols)
export(recover_supp_rows)
export(rename_cols)
export(rename_rows)
export(revert_conference)
export(revert_negation)
export(select_cols)
export(select_rows)
export(stat_bagplot)
export(stat_center)
export(stat_chull)
export(stat_cols)
export(stat_cols_bagplot)
export(stat_cols_center)
export(stat_cols_chull)
export(stat_cols_cone)
export(stat_cols_density_2d)
export(stat_cols_density_2d_filled)
export(stat_cols_depth)
export(stat_cols_depth_filled)
export(stat_cols_ellipse)
export(stat_cols_peel)
export(stat_cols_projection)
export(stat_cols_rule)
export(stat_cols_scale)
export(stat_cols_spantree)
export(stat_cols_star)
export(stat_cone)
export(stat_depth)
export(stat_depth_filled)
export(stat_peel)
export(stat_projection)
export(stat_rows)
export(stat_rows_bagplot)
export(stat_rows_center)
export(stat_rows_chull)
export(stat_rows_cone)
export(stat_rows_density_2d)
export(stat_rows_density_2d_filled)
export(stat_rows_depth)
export(stat_rows_depth_filled)
export(stat_rows_ellipse)
export(stat_rows_peel)
export(stat_rows_projection)
export(stat_rows_rule)
export(stat_rows_scale)
export(stat_rows_spantree)
export(stat_rows_star)
export(stat_rule)
export(stat_scale)
export(stat_spantree)
export(stat_star)
export(svd_ord)
export(sync)
export(theme_biplot)
export(theme_scaffold)
export(tidy)
export(transmute_cols)
export(transmute_rows)
export(un_tbl_ord)
export(valid_tbl_ord)
import(ggplot2)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,select)
importFrom(dplyr,transmute)
importFrom(generics,glance)
importFrom(generics,tidy)
importFrom(gggda,CoordRect)
importFrom(gggda,GeomAxis)
importFrom(gggda,GeomBagplot)
importFrom(gggda,GeomIsoline)
importFrom(gggda,GeomLineranges)
importFrom(gggda,GeomPointranges)
importFrom(gggda,GeomRule)
importFrom(gggda,GeomTextRadiate)
importFrom(gggda,GeomVector)
importFrom(gggda,StatBagplot)
importFrom(gggda,StatCenter)
importFrom(gggda,StatChull)
importFrom(gggda,StatCone)
importFrom(gggda,StatDepth)
importFrom(gggda,StatDepthFilled)
importFrom(gggda,StatPeel)
importFrom(gggda,StatReferent)
importFrom(gggda,StatRule)
importFrom(gggda,StatScale)
importFrom(gggda,StatSpantree)
importFrom(gggda,StatStar)
importFrom(gggda,geom_axis)
importFrom(gggda,geom_bagplot)
importFrom(gggda,geom_isoline)
importFrom(gggda,geom_lineranges)
importFrom(gggda,geom_pointranges)
importFrom(gggda,geom_rule)
importFrom(gggda,geom_text_radiate)
importFrom(gggda,geom_vector)
importFrom(gggda,maxpp)
importFrom(gggda,minabspp)
importFrom(gggda,minpp)
importFrom(gggda,stat_bagplot)
importFrom(gggda,stat_center)
importFrom(gggda,stat_chull)
importFrom(gggda,stat_cone)
importFrom(gggda,stat_depth)
importFrom(gggda,stat_depth_filled)
importFrom(gggda,stat_peel)
importFrom(gggda,stat_referent)
importFrom(gggda,stat_rule)
importFrom(gggda,stat_scale)
importFrom(gggda,stat_spantree)
importFrom(gggda,stat_star)
importFrom(ggrepel,GeomLabelRepel)
importFrom(ggrepel,GeomTextRepel)
importFrom(ggrepel,geom_label_repel)
importFrom(ggrepel,geom_text_repel)
importFrom(ggrepel,position_nudge_repel)
importFrom(graphics,plot)
importFrom(magrittr,"%>%")
importFrom(rlang,"%||%")
importFrom(rlang,as_function)
importFrom(rlang,enexpr)
importFrom(rlang,enexprs)
importFrom(rlang,enquo)
importFrom(rlang,expr)
importFrom(rlang,is_empty)
importFrom(rlang,is_formula)
importFrom(rlang,is_function)
importFrom(rlang,list2)
importFrom(rlang,set_names)
importFrom(stats,.checkMFClasses)
importFrom(stats,.getXlevels)
importFrom(stats,biplot)
importFrom(stats,cmdscale)
importFrom(stats,cooks.distance)
importFrom(stats,cor)
importFrom(stats,delete.response)
importFrom(stats,influence)
importFrom(stats,model.frame)
importFrom(stats,model.matrix)
importFrom(stats,model.response)
importFrom(stats,na.pass)
importFrom(stats,predict)
importFrom(stats,screeplot)
importFrom(stats,var)
importFrom(tibble,as_tibble)
importFrom(tibble,is_tibble)
importFrom(tibble,tibble)
importFrom(tidyselect,eval_select)
importFrom(tidyselect,one_of)
importFrom(utils,getFromNamespace)
